==> gnome-panel-2.26.0-i486-1sys.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database  &> /dev/null
fi

if [ -x /usr/bin/gtk-update-icon-cache ]; then
  /usr/bin/gtk-update-icon-cache  -f -q /usr/share/icons/hicolor  &> /dev/null
fi
#
( cd usr/share/gnome/help/clock/oc/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/oc/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/pt_BR/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/pt_BR/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/en_GB/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/en_GB/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/pa/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/pa/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/cs/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/cs/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/el/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/el/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/ru/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/ru/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/fish/oc/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/oc/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/fr/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/fr/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/en_GB/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/en_GB/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/th/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/th/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/eu/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/eu/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/sv/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/sv/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/el/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/el/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/ru/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/ru/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/de/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/de/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/ca/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/ca/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/lib ; rm -rf libpanel-applet-2.so )
( cd usr/lib ; ln -sf libpanel-applet-2.so.0.2.54 libpanel-applet-2.so )
( cd usr/lib ; rm -rf libpanel-applet-2.so.0 )
( cd usr/lib ; ln -sf libpanel-applet-2.so.0.2.54 libpanel-applet-2.so.0 )

==> gnome-panel-2.27.91-i486-1sys.tgz: install/doinst.sh <==
if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database &> /dev/null
fi

if [ -x /usr/bin/gtk-update-icon-cache ]; then
  /usr/bin/gtk-update-icon-cache  -f -q /usr/share/icons/hicolor &> /dev/null
fi
	# Update the scrollkeeper database (Remove stale pieces)
	if [ -x usr/bin/scrollkeeper-update ]; then
		usr/bin/scrollkeeper-update > /dev/null 2>&1
	fi
#
( cd usr/share/gnome/help/fish/es/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/es/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/oc/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/oc/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/en_GB/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/en_GB/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/it/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/it/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/cs/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/cs/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/ru/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/ru/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/sv/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/sv/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/eu/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/eu/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/el/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/el/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/fr/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/fr/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/ca/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/ca/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/de/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/de/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/fi/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/fi/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/zh_CN/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/zh_CN/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/fish/th/figures ; rm -rf fish_applet.png )
( cd usr/share/gnome/help/fish/th/figures ; ln -sf ../../C/figures/fish_applet.png fish_applet.png )
( cd usr/share/gnome/help/clock/oc/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/oc/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/en_GB/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/en_GB/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/pt_BR/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/pt_BR/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/cs/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/cs/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/ru/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/ru/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/pa/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/pa/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/share/gnome/help/clock/fi/figures ; rm -rf clock_applet.png )
( cd usr/share/gnome/help/clock/fi/figures ; ln -sf ../../C/figures/clock_applet.png clock_applet.png )
( cd usr/lib ; rm -rf libpanel-applet-2.so )
( cd usr/lib ; ln -sf libpanel-applet-2.so.0.2.58 libpanel-applet-2.so )
( cd usr/lib ; rm -rf libpanel-applet-2.so.0 )
( cd usr/lib ; ln -sf libpanel-applet-2.so.0.2.58 libpanel-applet-2.so.0 )
